Empty
Description
A centred empty-state with an optional icon, title, description and actions.
Usage
bc_empty(title = NULL, description = NULL, icon = NULL, actions = NULL, ...)
Arguments
| Argument | Description |
|---|---|
title |
String. The heading, rendered as an <h3>. |
description |
String. The helper text, rendered as a <p>. |
icon |
A tag. Content for the <figure>, typically an SVG. |
actions |
A tag or tag list. Content for the <footer>. |
... |
Attributes for the <section>, such as class. |
Value
A <section> tag.
Examples
bc_empty(
title = "No Projects Yet",
description = "Create your first project to get started.",
actions = bc_button("Create Project")
)
No Projects Yet
Create your first project to get started.
bc_empty(
title = "404 Not Found",
description = "The page you are looking for does not exist.",
actions = bc_input_group(
htmltools::tags$input(type = "search", placeholder = "Try searching..."),
htmltools::tags$span(`data-align` = "start", `aria-hidden` = "true")
),
class = "border border-dashed"
)
404 Not Found
The page you are looking for does not exist.